@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2014-2015 Harvard, edX & OpenCraft
 #
@@ -22,10 +21,9 @@
 
 import logging
 
-import six
+from web_fragments.fragment import Fragment
 from xblock.core import XBlock
 from xblock.fields import UNSET, JSONField, Scope, String
-from xblock.fragment import Fragment
 from xblockutils.resources import ResourceLoader
 from xblockutils.studio_editable import StudioEditableXBlockMixin
 
@@ -72,18 +70,23 @@ class NullableBoolean(JSONField):
     # We're OK redefining built-in `help`
     def __init__(self, help=None, default=UNSET, scope=Scope.content, display_name=None,
                  **kwargs):  # pylint: disable=redefined-builtin
-        super(NullableBoolean, self).__init__(help, default, scope, display_name,
-                                              values=({'display_name': "True", "value": True},
-                                                      {'display_name': "False", "value": False},
-                                                      {'display_name': "Null", "value": None}),
-                                              **kwargs)
+        super().__init__(
+            help,
+            default,
+            scope,
+            display_name,
+            values=({'display_name': "True", "value": True},
+                    {'display_name': "False", "value": False},
+                    {'display_name': "Null", "value": None}),
+            **kwargs
+        )
 
     def from_json(self, value):
         if value is None:
             return None
         if isinstance(value, str):
             value = value.decode('ascii', errors='replace')
-        if isinstance(value, six.text_type):
+        if isinstance(value, str):
             return value.lower() == 'true'
         else:
             return bool(value)
@@ -101,7 +104,7 @@ class CompletionBlock(
     The student's answer is always considered "correct".
     """
     CATEGORY = 'pb-completion'
-    STUDIO_LABEL = _(u'Completion')
+    STUDIO_LABEL = _('Completion')
     USER_STATE_FIELDS = ['student_value']
 
     answerable = True
@@ -144,7 +147,7 @@ class CompletionBlock(
         context['title'] = self.display_name_with_default
         context['hide_header'] = context.get('hide_header', False) or not self.show_title
 
-        html = loader.render_template('templates/html/completion.html', context)
+        html = loader.render_django_template('templates/html/completion.html', context)
 
         fragment = Fragment(html)
         fragment.add_javascript_url(self.runtime.local_resource_url(self, 'public/js/completion.js'))
@@ -161,7 +164,7 @@ class CompletionBlock(
         """
         return {
             'id': self.name,
-            'block_id': six.text_type(self.scope_ids.usage_id),
+            'block_id': str(self.scope_ids.usage_id),
             'display_name': self.display_name_with_default,
             'type': self.CATEGORY,
             'question': self.question,
@@ -190,11 +193,11 @@ class CompletionBlock(
         """
         Persist answer submitted by student.
         """
-        log.debug(u'Received Completion submission: "%s"', value)
+        log.debug('Received Completion submission: "%s"', value)
         self.student_value = value
         if sub_api:
             # Also send to the submissions API:
             sub_api.create_submission(self.student_item_key, value)
         result = self.get_last_result()
-        log.debug(u'Completion submission result: %s', result)
+        log.debug('Completion submission result: %s', result)
         return result
