@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2014-2015 Harvard, edX & OpenCraft
 #
@@ -26,12 +25,11 @@ from collections import namedtuple
 from decimal import ROUND_HALF_UP, Decimal
 from itertools import chain
 
-import six
 from lazy.lazy import lazy
+from web_fragments.fragment import Fragment
 from xblock.core import XBlock
 from xblock.exceptions import JsonHandlerError, NoSuchViewError
 from xblock.fields import Boolean, Float, Integer, List, Scope, String
-from xblock.fragment import Fragment
 from xblock.validation import ValidationMessage
 from xblockutils.helpers import child_isinstance
 from xblockutils.resources import ResourceLoader
@@ -53,7 +51,8 @@ from .message import MentoringMessageBlock, get_message_label
 from .mixins import (ExpandStaticURLMixin, MessageParentMixin, QuestionMixin,
                      StepParentMixin, StudentViewUserStateMixin,
                      StudentViewUserStateResultsTransformerMixin,
-                     XBlockWithTranslationServiceMixin, _normalize_id, TranslationContentMixin)
+                     TranslationContentMixin,
+                     XBlockWithTranslationServiceMixin, _normalize_id)
 from .step_review import ReviewStepBlock
 from .utils import I18NService
 
@@ -142,9 +141,9 @@ class BaseMentoringBlock(
         defer to super(). In the workbench or any other platform, we use the usage_id.
         """
         try:
-            return super(BaseMentoringBlock, self).url_name
+            return super().url_name
         except AttributeError:
-            return six.text_type(self.scope_ids.usage_id)
+            return str(self.scope_ids.usage_id)
 
     @property
     def review_tips_json(self):
@@ -214,7 +213,7 @@ class BaseMentoringBlock(
         authors in Studio when not editing this block's children.
         """
         fragment = self.student_view(context)
-        fragment.add_content(loader.render_template('templates/html/mentoring_url_name.html', {
+        fragment.add_content(loader.render_django_template('templates/html/mentoring_url_name.html', {
             "url_name": self.url_name
         }))
         fragment.add_css_url(self.runtime.local_resource_url(self, 'public/css/problem-builder-edit.css'))
@@ -335,32 +334,30 @@ class MentoringBlock(
         """
         additional_blocks = []
         try:
-            from xmodule.video_module.video_module import VideoDescriptor
+            from xmodule.video_module.video_module import VideoBlock
             additional_blocks.append(NestedXBlockSpec(
-                VideoDescriptor, category='video', label=_(u"Video")
+                VideoBlock, category='video', label=_("Video")
             ))
         except ImportError:
             pass
         try:
             from imagemodal import ImageModal
             additional_blocks.append(NestedXBlockSpec(
-                ImageModal, category='imagemodal', label=_(u"Image Modal")
+                ImageModal, category='imagemodal', label=_("Image Modal")
             ))
         except ImportError:
             pass
 
-        try:
-            from xblock_django.models import XBlockConfiguration
+        from .platform_dependencies import XBlockConfiguration
+        if XBlockConfiguration:
             opt = XBlockConfiguration.objects.filter(name="pb-swipe")
             if opt.count() and opt.first().enabled:
                 additional_blocks.append(SwipeBlock)
-        except ImportError:
-            pass
 
         try:
-            from ooyala_player import OoyalaPlayerBlock
+            from ooyala_player.ooyala_player import OoyalaPlayerBlock
             additional_blocks.append(NestedXBlockSpec(
-                OoyalaPlayerBlock, category='ooyala-player', label=_(u"Ooyala Player")
+                OoyalaPlayerBlock, category='ooyala-player', label=_("Ooyala Player")
             ))
         except ImportError:
             pass
@@ -422,7 +419,7 @@ class MentoringBlock(
         if total_child_weight == 0:
             return Score(0, 0, [], [], [])
         points_earned = 0
-        for q_name, q_details in self.student_results:
+        for q_name, q_details in self.student_results:  # pylint: disable=unbalanced-dict-unpacking
             question = steps_map.get(q_name)
             if question:
                 points_earned += q_details['score'] * question.weight
@@ -441,25 +438,25 @@ class MentoringBlock(
 
     @XBlock.supports("multi_device")  # Mark as mobile-friendly
     def student_view(self, context):
-        from .questionnaire import QuestionnaireAbstractBlock  # Import here to avoid circular dependency
+        from .questionnaire import \
+            QuestionnaireAbstractBlock  # Import here to avoid circular dependency
 
         # Migrate stored data if necessary
         self.migrate_fields()
 
         # Validate self.step:
         num_steps = len(self.steps)
-        if self.step > num_steps:
-            self.step = num_steps
+        self.step = min(num_steps, self.step)
 
         fragment = Fragment()
-        child_content = u""
+        child_content = ""
 
         mcq_hide_previous_answer = self.get_option('pb_mcq_hide_previous_answer')
 
         for child_id in self.children:
             child = self.runtime.get_block(child_id)
             if child is None:  # child should not be None but it can happen due to bugs or permission issues
-                child_content += u"<p>[{}]</p>".format(self._(u"Error: Unable to load child component."))
+                child_content += f'<p>[{self._("Error: Unable to load child component.")}]</p>'
             elif not isinstance(child, MentoringMessageBlock):
                 try:
                     if mcq_hide_previous_answer and isinstance(child, QuestionnaireAbstractBlock):
@@ -474,7 +471,7 @@ class MentoringBlock(
                         child_fragment = Fragment(child.data)
                     else:
                         child_fragment = child.render('student_view', context)
-                fragment.add_frag_resources(child_fragment)
+                fragment.add_fragment_resources(child_fragment)
                 child_content += child_fragment.content
 
         fragment.add_content(loader.render_django_template('templates/html/mentoring.html', {
@@ -534,7 +531,7 @@ class MentoringBlock(
         """
         Returns the URL of the next step's page
         """
-        return '/jump_to_id/{}'.format(self.next_step)
+        return f'/jump_to_id/{self.next_step}'
 
     @property
     def hide_feedback(self):
@@ -605,11 +602,12 @@ class MentoringBlock(
 
     @XBlock.json_handler
     def submit(self, submissions, suffix=''):
-        log.info(u'Received submissions: {}'.format(submissions))
+        log_message = f'Received submissions: {submissions}'
+        log.info(log_message)
         # server-side check that the user is allowed to submit:
         if self.max_attempts_reached:
             raise JsonHandlerError(403, "Maximum number of attempts already reached.")
-        elif self.has_missing_dependency:
+        if self.has_missing_dependency:
             raise JsonHandlerError(
                 403,
                 "You need to complete all previous steps before being able to complete the current one."
@@ -711,7 +709,7 @@ class MentoringBlock(
         """
         Validates the state of this XBlock except for individual field values.
         """
-        validation = super(MentoringBlock, self).validate()
+        validation = super().validate()
         a_child_has_issues = False
         message_types_present = set()
         for child_id in self.children:
@@ -725,13 +723,13 @@ class MentoringBlock(
                 if msg_type in message_types_present:
                     validation.add(ValidationMessage(
                         ValidationMessage.ERROR,
-                        self._(u"There should only be one '{msg_type}' message component.").format(msg_type=msg_type)
+                        self._("There should only be one '{msg_type}' message component.").format(msg_type=msg_type)
                     ))
                 message_types_present.add(msg_type)
         if a_child_has_issues:
             validation.add(ValidationMessage(
                 ValidationMessage.ERROR,
-                self._(u"A component inside this mentoring block has issues.")
+                self._("A component inside this mentoring block has issues.")
             ))
         return validation
 
@@ -741,8 +739,8 @@ class MentoringBlock(
         """
         local_context = context.copy()
         local_context['author_edit_view'] = True
-        fragment = super(MentoringBlock, self).author_edit_view(local_context)
-        fragment.add_content(loader.render_template('templates/html/mentoring_url_name.html', {
+        fragment = super().author_edit_view(local_context)
+        fragment.add_content(loader.render_django_template('templates/html/mentoring_url_name.html', {
             'url_name': self.url_name
         }))
         fragment.add_css_url(self.runtime.local_resource_url(self, 'public/css/problem-builder.css'))
@@ -773,7 +771,7 @@ class MentoringBlock(
                 components.append(block.student_view_data())
 
         return {
-            'block_id': six.text_type(self.scope_ids.usage_id),
+            'block_id': str(self.scope_ids.usage_id),
             'display_name': self.display_name,
             'max_attempts': self.max_attempts,
             'extended_feedback': self.extended_feedback,
@@ -824,7 +822,7 @@ class MentoringWithExplicitStepsBlock(BaseMentoringBlock, StudioContainerWithNes
     editable_fields = ('display_name', 'max_attempts', 'extended_feedback', 'weight')
 
     def build_user_state_data(self, context=None):
-        user_state_data = super(MentoringWithExplicitStepsBlock, self).build_user_state_data()
+        user_state_data = super().build_user_state_data()
         user_state_data['active_step'] = self.active_step_safe
         user_state_data['score_summary'] = self.get_score_summary()
         return user_state_data
@@ -851,7 +849,7 @@ class MentoringWithExplicitStepsBlock(BaseMentoringBlock, StudioContainerWithNes
         added/deleted.
         """
         active_step = self.active_step
-        if active_step >= 0 and active_step < len(self.step_ids):
+        if 0 <= active_step < len(self.step_ids):
             return active_step
         if active_step == -1 and self.has_review_step:
             return active_step  # -1 indicates the review step
@@ -869,7 +867,8 @@ class MentoringWithExplicitStepsBlock(BaseMentoringBlock, StudioContainerWithNes
         """
         Get the usage_ids of all of this XBlock's children that are steps.
         """
-        from .step import MentoringStepBlock  # Import here to avoid circular dependency
+        from .step import \
+            MentoringStepBlock  # Import here to avoid circular dependency
         return [
             _normalize_id(child_id) for child_id in self.children if
             child_isinstance(self, child_id, MentoringStepBlock)
@@ -892,12 +891,15 @@ class MentoringWithExplicitStepsBlock(BaseMentoringBlock, StudioContainerWithNes
         for step in steps:
             for answer in step.student_results:
                 if answer[1]['status'] == answer_status:
-                    answer_map.append({
-                        'id': answer[0],
-                        'details': answer[1],
-                        'step': step.step_number,
-                        'number': self.get_question_number(answer[0]),
-                    })
+                    try:
+                        answer_map.append({
+                            'id': answer[0],
+                            'details': answer[1],
+                            'step': step.step_number,
+                            'number': self.get_question_number(answer[0]),
+                        })
+                    except ValueError:
+                        pass  # The question has been deleted since the student answered it.
         return answer_map
 
     @property
@@ -949,7 +951,7 @@ class MentoringWithExplicitStepsBlock(BaseMentoringBlock, StudioContainerWithNes
             # Review tips are only shown if the student is allowed to try again.
             return []
         review_tips = []
-        status_cache = dict()
+        status_cache = {}
         steps = self.steps
         for step in steps:
             status_cache.update(dict(step.student_results))
@@ -978,10 +980,10 @@ class MentoringWithExplicitStepsBlock(BaseMentoringBlock, StudioContainerWithNes
         for child_id in self.children:
             child = self.runtime.get_block(child_id)
             if child is None:  # child should not be None but it can happen due to bugs or permission issues
-                child_content = u"<p>[{}]</p>".format(self._(u"Error: Unable to load child component."))
+                child_content = f'<p>[{self._("Error: Unable to load child component.")}]</p>'
             else:
                 child_fragment = self._render_child_fragment(child, context, view='mentoring_view')
-                fragment.add_frag_resources(child_fragment)
+                fragment.add_fragment_resources(child_fragment)
                 child_content = child_fragment.content
             children_contents.append(child_content)
 
@@ -1105,8 +1107,8 @@ class MentoringWithExplicitStepsBlock(BaseMentoringBlock, StudioContainerWithNes
         """
         Add some HTML to the author view that allows authors to add child blocks.
         """
-        fragment = super(MentoringWithExplicitStepsBlock, self).author_edit_view(context)
-        fragment.add_content(loader.render_template('templates/html/mentoring_url_name.html', {
+        fragment = super().author_edit_view(context)
+        fragment.add_content(loader.render_django_template('templates/html/mentoring_url_name.html', {
             "url_name": self.url_name
         }))
         fragment.add_css_url(self.runtime.local_resource_url(self, 'public/css/problem-builder.css'))
@@ -1127,7 +1129,7 @@ class MentoringWithExplicitStepsBlock(BaseMentoringBlock, StudioContainerWithNes
 
         return {
             'title': self.display_name,
-            'block_id': six.text_type(self.scope_ids.usage_id),
+            'block_id': str(self.scope_ids.usage_id),
             'display_name': self.display_name,
             'show_title': self.show_title,
             'weight': self.weight,
