@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.db import migrations, models
 
 
@@ -17,13 +14,13 @@ class Migration(migrations.Migration):
                 ('name', models.CharField(max_length=50, db_index=True)),
                 ('student_id', models.CharField(max_length=32, db_index=True)),
                 ('course_id', models.CharField(max_length=50, db_index=True)),
-                ('student_input', models.TextField(default=u'', blank=True)),
-                ('created_on', models.DateTimeField(auto_now_add=True, verbose_name=u'created on')),
-                ('modified_on', models.DateTimeField(auto_now=True, verbose_name=u'modified on')),
+                ('student_input', models.TextField(default='', blank=True)),
+                ('created_on', models.DateTimeField(auto_now_add=True, verbose_name='created on')),
+                ('modified_on', models.DateTimeField(auto_now=True, verbose_name='modified on')),
             ],
         ),
         migrations.AlterUniqueTogether(
             name='answer',
-            unique_together=set([('student_id', 'course_id', 'name')]),
+            unique_together={('student_id', 'course_id', 'name')},
         ),
     ]
