@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.conf import settings
 from django.db import migrations, models
 
@@ -20,12 +17,12 @@ class Migration(migrations.Migration):
                 ('submission_uid', models.CharField(max_length=32)),
                 ('block_id', models.CharField(max_length=255, db_index=True)),
                 ('notified', models.BooleanField(default=False, db_index=True)),
-                ('shared_by', models.ForeignKey(related_name='problem_builder_shared_by', to=settings.AUTH_USER_MODEL)),
-                ('shared_with', models.ForeignKey(related_name='problem_builder_shared_with', to=settings.AUTH_USER_MODEL)),
+                ('shared_by', models.ForeignKey(related_name='problem_builder_shared_by', on_delete=models.CASCADE, to=settings.AUTH_USER_MODEL)),
+                ('shared_with', models.ForeignKey(related_name='problem_builder_shared_with', on_delete=models.CASCADE, to=settings.AUTH_USER_MODEL)),
             ],
         ),
         migrations.AlterUniqueTogether(
             name='share',
-            unique_together=set([('shared_by', 'shared_with', 'block_id')]),
+            unique_together={('shared_by', 'shared_with', 'block_id')},
         ),
     ]
