@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.db import migrations, models
 
 
@@ -18,6 +15,6 @@ class Migration(migrations.Migration):
         ),
         migrations.AlterUniqueTogether(
             name='answer',
-            unique_together=set([('student_id', 'course_key', 'name'), ('student_id', 'course_id', 'name')]),
+            unique_together={('student_id', 'course_key', 'name'), ('student_id', 'course_id', 'name')},
         ),
     ]
