@@ -1,14 +1,12 @@
 import json
 
 import pkg_resources
-import six
 import webob
 from django import utils
 from lazy import lazy
-from .settings import PB_LANGUAGE_JS_DIRECTORY_MAP
+from web_fragments.fragment import Fragment
 from xblock.core import XBlock
 from xblock.fields import UNIQUE_ID, Boolean, Float, Scope, String
-from xblock.fragment import Fragment
 from xblockutils.helpers import child_isinstance
 from xblockutils.resources import ResourceLoader
 
@@ -16,6 +14,20 @@ from problem_builder.tests.unit.utils import DateTimeEncoder
 
 loader = ResourceLoader(__name__)
 
+PB_LANGUAGE_JS_DIRECTORY_MAP = {
+    'ar': 'ar',
+    'de-de': 'de_DE',
+    'en': 'en',
+    'es-419': 'es_419',
+    'fr': 'fr',
+    'fr-ca': 'fr_CA',
+    'ja-jp': 'ja_JP',
+    'pl': 'pl_PL',
+    'pt-br': 'pt_BR',
+    'zh-cn': 'zh_CN',
+    'ko-kr': 'ko_KR'
+}
+
 
 # Make '_' a no-op so we can scrape strings
 def _(text):
@@ -34,7 +46,7 @@ def _normalize_id(key):
     return key
 
 
-class XBlockWithTranslationServiceMixin(object):
+class XBlockWithTranslationServiceMixin:
     """
     Mixin providing access to i18n service
     """
@@ -44,7 +56,7 @@ class XBlockWithTranslationServiceMixin(object):
 
 
 class EnumerableChildMixin(XBlockWithTranslationServiceMixin):
-    CAPTION = _(u"Child")
+    CAPTION = _("Child")
 
     show_title = Boolean(
         display_name=_("Show title"),
@@ -67,7 +79,7 @@ class EnumerableChildMixin(XBlockWithTranslationServiceMixin):
     @lazy
     def lonely_child(self):
         if _normalize_id(self.scope_ids.usage_id) not in self.siblings:
-            message = u"{child_caption}'s parent should contain {child_caption}".format(child_caption=self.CAPTION)
+            message = "{child_caption}'s parent should contain {child_caption}".format(child_caption=self.CAPTION)
             raise ValueError(message, self, self.siblings)
         return len(self.siblings) == 1
 
@@ -77,13 +89,13 @@ class EnumerableChildMixin(XBlockWithTranslationServiceMixin):
         if self.display_name:
             return self.display_name
         if not self.lonely_child:
-            return self._(u"{child_caption} {number}").format(
+            return self._("{child_caption} {number}").format(
                 child_caption=self.CAPTION, number=self.step_number
             )
         return self._(self.CAPTION)
 
 
-class StepParentMixin(object):
+class StepParentMixin:
     """
     An XBlock mixin for a parent block containing Step children
     """
@@ -103,13 +115,14 @@ class StepParentMixin(object):
         return [self.runtime.get_block(child_id) for child_id in self.step_ids]
 
 
-class MessageParentMixin(object):
+class MessageParentMixin:
     """
     An XBlock mixin for a parent block containing MentoringMessageBlock children
     """
 
     def get_message_content(self, message_type, or_default=False):
-        from problem_builder.message import MentoringMessageBlock  # Import here to avoid circular dependency
+        from problem_builder.message import \
+            MentoringMessageBlock  # Import here to avoid circular dependency
         for child_id in self.children:
             if child_isinstance(self, child_id, MentoringMessageBlock):
                 child = self.runtime.get_block(child_id)
@@ -121,7 +134,7 @@ class MessageParentMixin(object):
         if or_default:
             # Return the default value since no custom message is set.
             # Note the WYSIWYG editor usually wraps the .content HTML in a <p> tag so we do the same here.
-            return '<p>{}</p>'.format(MentoringMessageBlock.MESSAGE_TYPES[message_type]['default'])
+            return f'<p>{MentoringMessageBlock.MESSAGE_TYPES[message_type]["default"]}</p>'
 
 
 class QuestionMixin(EnumerableChildMixin):
@@ -130,7 +143,7 @@ class QuestionMixin(EnumerableChildMixin):
 
     A step is a question that the user can answer (as opposed to a read-only child).
     """
-    CAPTION = _(u"Question")
+    CAPTION = _("Question")
 
     has_author_view = True
 
@@ -170,15 +183,15 @@ class QuestionMixin(EnumerableChildMixin):
         return self.student_view(context)
 
 
-class NoSettingsMixin(object):
+class NoSettingsMixin:
     """ Mixin for an XBlock that has no settings """
 
     def studio_view(self, _context=None):
         """ Studio View """
-        return Fragment(u'<p>{}</p>'.format(self._("This XBlock does not have any settings.")))
+        return Fragment(f'<p>{self._("This XBlock does not have any settings.")}</p>')
 
 
-class StudentViewUserStateMixin(object):
+class StudentViewUserStateMixin:
     """
     Mixin to provide student_view_user_state view.
 
@@ -206,7 +219,7 @@ class StudentViewUserStateMixin(object):
 
         result = {}
         transforms = self.transforms()
-        for _, field in six.iteritems(self.fields):
+        for _, field in self.fields.items():
             # Only insert fields if their scopes and field names match
             if field.scope in self.INCLUDE_SCOPES and field.name in self.USER_STATE_FIELDS:
                 transformer = transforms.get(field.name, lambda value: value)
@@ -237,7 +250,7 @@ class StudentViewUserStateMixin(object):
         )
 
 
-class StudentViewUserStateResultsTransformerMixin(object):
+class StudentViewUserStateResultsTransformerMixin:
     """
     A convenient way for MentoringBlock and MentoringStepBlock to share
     student_results transform code.
@@ -270,7 +283,7 @@ class StudentViewUserStateResultsTransformerMixin(object):
         return dictionary
 
 
-class ExpandStaticURLMixin(object):
+class ExpandStaticURLMixin:
 
     def expand_static_url(self, text):
         """
@@ -287,15 +300,13 @@ class ExpandStaticURLMixin(object):
         elif hasattr(self.runtime, 'course_id'):
             # edX Studio uses a different runtime for 'studio_view' than 'student_view',
             # and the 'studio_view' runtime doesn't provide the replace_urls API.
-            try:
-                from static_replace import replace_static_urls  # pylint: disable=import-error
+            from .platform_dependencies import replace_static_urls
+            if replace_static_urls:
                 text = replace_static_urls(text, course_id=self.runtime.course_id)
-            except ImportError:
-                pass
         return text
 
 
-class TranslationContentMixin(object):
+class TranslationContentMixin:
     """
     Mixin to provide the translation content
     """
@@ -313,6 +324,6 @@ class TranslationContentMixin(object):
             # i.e for polish language code is pl but js directory is pl_PL
             # to coup this behaviour PB_LANGUAGES_JS_DIRECTORY_MAP is added to get the desired directory.
             js_directory = PB_LANGUAGE_JS_DIRECTORY_MAP.get(language, 'en')
-            return self.resource_string('public/js/translations/{lang}/textjs.js'.format(lang=js_directory))
-        except IOError:
+            return self.resource_string(f'public/js/translations/{js_directory}/textjs.js')
+        except OSError:
             return self.resource_string('public/js/translations/en/textjs.js')
