@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2014-2015 Harvard, edX & OpenCraft
 #
@@ -20,11 +19,10 @@
 
 import logging
 
-import six
 from lazy.lazy import lazy
+from web_fragments.fragment import Fragment
 from xblock.core import XBlock
 from xblock.fields import List, Scope, String
-from xblock.fragment import Fragment
 from xblockutils.resources import ResourceLoader
 from xblockutils.studio_editable import (NestedXBlockSpec,
                                          StudioContainerWithNestedXBlocksMixin,
@@ -41,8 +39,8 @@ from problem_builder.mrq import MRQBlock
 from problem_builder.plot import PlotBlock
 from problem_builder.slider import SliderBlock
 from problem_builder.table import MentoringTableBlock
-from .mixins import TranslationContentMixin
 
+from .mixins import TranslationContentMixin
 from .utils import I18NService
 
 log = logging.getLogger(__name__)
@@ -66,7 +64,7 @@ def _normalize_id(key):
     return key
 
 
-class Correctness(object):
+class Correctness:
     CORRECT = 'correct'
     PARTIAL = 'partial'
     INCORRECT = 'incorrect'
@@ -81,8 +79,8 @@ class MentoringStepBlock(
     """
     An XBlock for a step.
     """
-    CAPTION = _(u"Step")
-    STUDIO_LABEL = _(u"Mentoring Step")
+    CAPTION = _("Step")
+    STUDIO_LABEL = _("Mentoring Step")
     CATEGORY = 'sb-step'
     USER_STATE_FIELDS = ['student_results']
 
@@ -121,7 +119,7 @@ class MentoringStepBlock(
     @property
     def is_last_step(self):
         parent = self.get_parent()
-        return self.step_number == len(parent.step_ids)
+        return self.step_number == len(parent.step_ids)  # pylint: disable=comparison-with-callable
 
     @property
     def allowed_nested_blocks(self):
@@ -136,24 +134,24 @@ class MentoringStepBlock(
         """
         additional_blocks = []
         try:
-            from xmodule.video_module.video_module import VideoDescriptor
+            from xmodule.video_module.video_module import VideoBlock
             additional_blocks.append(NestedXBlockSpec(
-                VideoDescriptor, category='video', label=_(u"Video")
+                VideoBlock, category='video', label=_("Video")
             ))
         except ImportError:
             pass
         try:
             from imagemodal import ImageModal
             additional_blocks.append(NestedXBlockSpec(
-                ImageModal, category='imagemodal', label=_(u"Image Modal")
+                ImageModal, category='imagemodal', label=_("Image Modal")
             ))
         except ImportError:
             pass
 
         try:
-            from ooyala_player import OoyalaPlayerBlock
+            from ooyala_player.ooyala_player import OoyalaPlayerBlock
             additional_blocks.append(NestedXBlockSpec(
-                OoyalaPlayerBlock, category='ooyala-player', label=_(u"Ooyala Player")
+                OoyalaPlayerBlock, category='ooyala-player', label=_("Ooyala Player")
             ))
         except ImportError:
             pass
@@ -171,7 +169,8 @@ class MentoringStepBlock(
 
     def submit(self, submissions):
         """ Handle a student submission. This is called by the parent XBlock. """
-        log.info(u'Received submissions: {}'.format(submissions))
+        log_message = f'Received submissions: {submissions}'
+        log.info(log_message)
 
         # Submit child blocks (questions) and gather results
         submit_results = []
@@ -229,7 +228,7 @@ class MentoringStepBlock(
         """
         local_context = dict(context)
         local_context['author_edit_view'] = True
-        fragment = super(MentoringStepBlock, self).author_edit_view(local_context)
+        fragment = super().author_edit_view(local_context)
         fragment.add_css_url(self.runtime.local_resource_url(self, 'public/css/problem-builder.css'))
         fragment.add_css_url(self.runtime.local_resource_url(self, 'public/css/problem-builder-edit.css'))
         fragment.add_css_url(self.runtime.local_resource_url(self, 'public/css/problem-builder-tinymce-content.css'))
@@ -254,7 +253,7 @@ class MentoringStepBlock(
         for child_id in self.children:
             child = self.runtime.get_block(child_id)
             if child is None:  # child should not be None but it can happen due to bugs or permission issues
-                child_contents.append(u"<p>[{}]</p>".format(self._(u"Error: Unable to load child component.")))
+                child_contents.append(f'<p>[{self._("Error: Unable to load child component.")}]</p>')
             else:
                 if rendering_for_studio and isinstance(child, PlotBlock):
                     # Don't use view to render plot blocks in Studio.
@@ -263,10 +262,10 @@ class MentoringStepBlock(
                     #   which causes "SubmissionRequestError" in Studio.
                     # - author_preview_view does not supply JS code for plot that JS code for step depends on
                     #   (step calls "update" on plot to get latest data during rendering).
-                    child_contents.append(u"<p>{}</p>".format(child.display_name))
+                    child_contents.append(f"<p>{child.display_name}</p>")
                 else:
                     child_fragment = self._render_child_fragment(child, context, view)
-                    fragment.add_frag_resources(child_fragment)
+                    fragment.add_fragment_resources(child_fragment)
                     child_contents.append(child_fragment.content)
 
         fragment.add_content(loader.render_django_template('templates/html/step.html', {
@@ -295,7 +294,7 @@ class MentoringStepBlock(
                 components.append(child.student_view_data(context))
 
         return {
-            'block_id': six.text_type(self.scope_ids.usage_id),
+            'block_id': str(self.scope_ids.usage_id),
             'display_name': self.display_name_with_default,
             'type': self.CATEGORY,
             'title': self.display_name_with_default,
