@@ -1,7 +1,7 @@
 import copy
 import unittest
+from unittest.mock import MagicMock, Mock
 
-from mock import MagicMock, Mock
 from xblock.field_data import DictFieldData
 
 from problem_builder.mentoring import MentoringBlock
@@ -18,16 +18,16 @@ class TestFieldMigration(unittest.TestCase):
         """
         # Instantiate a mentoring block with the old format
         student_results = [
-            [u'goal',
-                {u'completed': True,
-                 u'score': 1,
-                 u'student_input': u'test',
-                 u'weight': 1}],
-            [u'mcq_1_1',
-                {u'completed': False,
-                 u'score': 0,
-                 u'submission': u'maybenot',
-                 u'weight': 1}],
+            ['goal',
+                {'completed': True,
+                 'score': 1,
+                 'student_input': 'test',
+                 'weight': 1}],
+            ['mcq_1_1',
+                {'completed': False,
+                 'score': 0,
+                 'submission': 'maybenot',
+                 'weight': 1}],
         ]
         mentoring = MentoringBlock(MagicMock(), DictFieldData({'student_results': student_results}), Mock())
         self.assertEqual(copy.deepcopy(student_results), mentoring.student_results)
